@@ -322,19 +322,25 @@ class Serialize(SerializerUtils):
     def serialize(
             self,
             xml_filename: Optional[str] = None,
+            xml_header: Optional[str] = False,
+
     ) -> None:
         self._set_class_vars()
         parent = self.root
         self._serialize(self, parent)
         if xml_filename is not None:
-            self._write_xml(xml_filename)
+            self._write_xml(xml_filename, xml_header)
         self._delete_class_vars()
 
     def _write_xml(
             self,
             xml_filename: str,
+            xml_header: str,
     ) -> None:
         xmlstr = self.doc.toprettyxml(indent="	  ")
+        if xml_header:
+            xmlstr = xmlstr.replace(f'?>\n', f'?>\n<!--{xml_header}-->\n', 1)
         xml_file = open(xml_filename, 'w')
         xml_file.write(xmlstr)
         xml_file.close()
+
